==> zio-aws-sagemaker_2.12-5.17.129.1-sources.jar: zio/aws/sagemaker/model/MonitoringBaselineConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.ProcessingJobName
import scala.jdk.CollectionConverters._
final case class MonitoringBaselineConfig(
    baseliningJobName: Option[ProcessingJobName] = None,
    constraintsResource: Option[
      zio.aws.sagemaker.model.MonitoringConstraintsResource
    ] = None,
    statisticsResource: Option[
      zio.aws.sagemaker.model.MonitoringStatisticsResource
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig = {
    import MonitoringBaselineConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
      .builder()
      .optionallyWith(
        baseliningJobName.map(value =>
          ProcessingJobName.unwrap(value): java.lang.String
        )
      )(_.baseliningJobName)
      .optionallyWith(constraintsResource.map(value => value.buildAwsValue()))(
        _.constraintsResource
      )
      .optionallyWith(statisticsResource.map(value => value.buildAwsValue()))(
        _.statisticsResource
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly =
    zio.aws.sagemaker.model.MonitoringBaselineConfig.wrap(buildAwsValue())
}
object MonitoringBaselineConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.MonitoringBaselineConfig =
      zio.aws.sagemaker.model.MonitoringBaselineConfig(
        baseliningJobName.map(value => value),
        constraintsResource.map(value => value.asEditable),
        statisticsResource.map(value => value.asEditable)
      )
    def baseliningJobName: Option[ProcessingJobName]
    def constraintsResource
        : Option[zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly]
    def statisticsResource
        : Option[zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly]
    def getBaseliningJobName: ZIO[Any, AwsError, ProcessingJobName] =
      AwsError.unwrapOptionField("baseliningJobName", baseliningJobName)
    def getConstraintsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = AwsError.unwrapOptionField("constraintsResource", constraintsResource)
    def getStatisticsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly
    ] = AwsError.unwrapOptionField("statisticsResource", statisticsResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ) extends zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly {
    override val baseliningJobName: Option[ProcessingJobName] = scala
      .Option(impl.baseliningJobName())
      .map(value => zio.aws.sagemaker.model.primitives.ProcessingJobName(value))
    override val constraintsResource: Option[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = scala
      .Option(impl.constraintsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(value)
      )
    override val statisticsResource: Option[
      zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly
    ] = scala
      .Option(impl.statisticsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringStatisticsResource.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ): zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/MonitoringBaselineConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.ProcessingJobName
import scala.jdk.CollectionConverters._
final case class MonitoringBaselineConfig(
    baseliningJobName: Optional[ProcessingJobName] = Optional.Absent,
    constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource
    ] = Optional.Absent,
    statisticsResource: Optional[
      zio.aws.sagemaker.model.MonitoringStatisticsResource
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig = {
    import MonitoringBaselineConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
      .builder()
      .optionallyWith(
        baseliningJobName.map(value =>
          ProcessingJobName.unwrap(value): java.lang.String
        )
      )(_.baseliningJobName)
      .optionallyWith(constraintsResource.map(value => value.buildAwsValue()))(
        _.constraintsResource
      )
      .optionallyWith(statisticsResource.map(value => value.buildAwsValue()))(
        _.statisticsResource
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly =
    zio.aws.sagemaker.model.MonitoringBaselineConfig.wrap(buildAwsValue())
}
object MonitoringBaselineConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.MonitoringBaselineConfig =
      zio.aws.sagemaker.model.MonitoringBaselineConfig(
        baseliningJobName.map(value => value),
        constraintsResource.map(value => value.asEditable),
        statisticsResource.map(value => value.asEditable)
      )
    def baseliningJobName: Optional[ProcessingJobName]
    def constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ]
    def statisticsResource: Optional[
      zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly
    ]
    def getBaseliningJobName: ZIO[Any, AwsError, ProcessingJobName] =
      AwsError.unwrapOptionField("baseliningJobName", baseliningJobName)
    def getConstraintsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = AwsError.unwrapOptionField("constraintsResource", constraintsResource)
    def getStatisticsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly
    ] = AwsError.unwrapOptionField("statisticsResource", statisticsResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ) extends zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly {
    override val baseliningJobName: Optional[ProcessingJobName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.baseliningJobName())
        .map(value =>
          zio.aws.sagemaker.model.primitives.ProcessingJobName(value)
        )
    override val constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.constraintsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(value)
      )
    override val statisticsResource: Optional[
      zio.aws.sagemaker.model.MonitoringStatisticsResource.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.statisticsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringStatisticsResource.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringBaselineConfig
  ): zio.aws.sagemaker.model.MonitoringBaselineConfig.ReadOnly = new Wrapper(
    impl
  )
}
